==> mysql-5.7.38.tar.gz: mysql-5.7.38/storage/myisam/sp_defs.h <==
/* Copyright (c) 2002, 2021, Oracle and/or its affiliates.
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA */

#ifndef _SP_DEFS_H
#define _SP_DEFS_H

#define SPDIMS 2
#define SPTYPE HA_KEYTYPE_DOUBLE
#define SPLEN  8

enum wkbType
{
  wkbPoint = 1,
  wkbLineString = 2,
  wkbPolygon = 3,
  wkbMultiPoint = 4,
  wkbMultiLineString = 5,
  wkbMultiPolygon = 6,
  wkbGeometryCollection = 7
};

enum wkbByteOrder
{
  wkbXDR = 0,    /* Big Endian    */
  wkbNDR = 1     /* Little Endian */
};                                    

uint sp_make_key(MI_INFO *info, uint keynr, uchar *key,
                 const uchar *record, my_off_t filepos);

#endif /* _SP_DEFS_H */

==> mysql-8.0_8.0.44.orig.tar.gz: mysql-8.0.44/storage/myisam/sp_defs.h <==
/* Copyright (c) 2002, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef _SP_DEFS_H
#define _SP_DEFS_H

/**
  @file storage/myisam/sp_defs.h
*/

#define SPDIMS 2
#define SPTYPE HA_KEYTYPE_DOUBLE
#define SPLEN 8

enum wkbType {
  wkbPoint = 1,
  wkbLineString = 2,
  wkbPolygon = 3,
  wkbMultiPoint = 4,
  wkbMultiLineString = 5,
  wkbMultiPolygon = 6,
  wkbGeometryCollection = 7
};

enum wkbByteOrder {
  wkbXDR = 0, /* Big Endian    */
  wkbNDR = 1  /* Little Endian */
};

uint sp_make_key(MI_INFO *info, uint keynr, uchar *key, const uchar *record,
                 my_off_t filepos);

#endif /* _SP_DEFS_H */
